Given some summary stats file, construct a name for the resulting sorted, bgzip-compressed tabix file.
See also
Other tabix functions:
construct_vcf_path(),
convert(),
index,
query_table(),
query_vcf(),
read_bgz(),
run_bgzip()
Given some summary stats file, construct a name for the resulting sorted, bgzip-compressed tabix file.
Other tabix functions:
construct_vcf_path(),
convert(),
index,
query_table(),
query_vcf(),
read_bgz(),
run_bgzip()