Convert a tabular file to compressed (bgzip), indexed, tabix format for rapid querying.
Usage
convert(
target_path,
bgz_file = construct_tabix_path(target_path = target_path),
chrom_col = "CHR",
start_col = "POS",
end_col = start_col,
comment_char = NULL,
format = NULL,
convert_methods = list(sort_coordinates = if (.Platform$OS.type == "windows")
"data.table" else "bash", run_bgzip = "Rsamtools", index = "Rsamtools"),
conda_env = "echoR_mini",
force_new = TRUE,
verbose = TRUE
)Source
Rhtslib (which Rsamtools and seqminer depend on for tabix) is very out of date (1.7 vs. 1.15).
conda install tabix was recently fixed so it installs htslib
Arguments
- target_path
Path to full GWAS/QTL summary statistics file.
- bgz_file
Path to resulting bgz-compressed file after
target_pathhas been converted to tabix format.- chrom_col
Name of the chromosome column in the
target_pathfile.- start_col
Name of the genomic start position column in the
target_pathfile.- end_col
Name of the genomic end position column in the
target_pathfile.- comment_char
A single character which, when present as the first character in a line, indicates that the line is to be omitted from indexing.
- format
Format of the
target_pathfile: "vcf" or "table".- convert_methods
A named list containing methods to run each step with.
- conda_env
Conda environments to search in. If
NULL(default), will search all conda environments.- force_new
Force the creation of a new bgzip file (.bgz) and a new tabix index file (.tbi).
- verbose
Print messages.
See also
Other tabix functions:
construct_tabix_path(),
construct_vcf_path(),
index,
query_table(),
query_vcf(),
read_bgz(),
run_bgzip()