Decompress a file using gunzip.
Arguments
- path
Path to file.
- conda_env
Conda environments to search in. If
NULL(default), will search all conda environments.- method
Method to gunzip
pathwith:- "conda":
Finds gunzip binary in the specified
conda_envand uses it.- "R.utils":
Uses the gunzip function.
- outputs
Which outputs to return in a list. Can be one or more of the following:
- "command" :
The command run to gunzip the file.
- "path" :
Path to the gunzipped file.
- "data" :
The data imported from the gunzipped file.
If only one valid option is selected, the item will be returned without being embedded within a list.
- verbose
Print messages.