Sort a table of summary statistics by their genomic coordinates without reading the file into R.
Arguments
- target_path
Path to full GWAS/QTL summary statistics file.
- chrom_col
Name of the chromosome column in the
target_pathfile.- start_col
Name of the genomic start position column in the
target_pathfile.- end_col
Name of the genomic end position column in the
target_pathfile.- comment_char
A single character which, when present as the first character in a line, indicates that the line is to be omitted from indexing.
- save_path
File to save the results to.
- method
Method to sort coordinates with.
- outputs
- "command"
Text string of the command (without executing it.)
- "path"
Path to the saved data file.
- "data"
The resulting data in data.table format.
- verbose
Print messages.